@@ -72,6 +72,15 @@ def read_yaml(config_path, config_name=''):
         raise ValueError('请输入正确的配置名称或配置文件路径')
 
 
+def save_yaml(name, content, mode='w+'):
+    try:
+        with open(name, mode, encoding='utf-8') as f:
+            yaml.safe_dump(content, f, allow_unicode=True)
+            return True
+    except Exception as e:
+        raise IOError('yml文件写入错误-{}'.format(e))
+
+
 def round_read_yaml(path):
     """
     保留yaml所有注释，锚点的读取
