@@ -1,8 +1,8 @@
 import re
-import socket
 import json
 import logging
 from IPy import IP, IPSet
+from tld import get_tld
 from .html import get_html, post_data
 
 logger = logging.getLogger(__name__)
@@ -12,9 +12,9 @@ INTERNAL_IP_LIST = ['10.0.0.0/8', '127.0.0.0/8', '172.16.0.0/12', '192.168.0.0/1
 MASK = [128, 192, 224, 240, 248, 252, 254, 255]
 
 
-def get_addr_from_ip_by_whois(target):
+def get_addr_from_ip_by_whois(ip):
     try:
-        api = f'http://whois.pconline.com.cn/ipJson.jsp?ip={target}&json=true'
+        api = f'http://whois.pconline.com.cn/ipJson.jsp?ip={ip}&json=true'
         info = get_html(api)
         info = json.loads(info)
         info = json.loads(info)
@@ -55,12 +55,22 @@ def get_fingerprint_from_ip_by_whatweb(target):
     return json.loads(res.text)
 
 
-def is_domain(domain):
-    """判断是否是域名"""
-    if re.match('(.+?\.)+[a-zA-Z0-9]+', domain):
-        res = True
+def is_domain(domain, use_tld=False):
+    """判断是否是域名,use_tld会判断的更加精准一些，但是会耗费时间（大概20倍）"""
+    res = True
+
+    if '.' not in domain:
+        return False
+    if not use_tld:
+        if re.match('(.+?\.)+[a-zA-Z0-9]+', domain):
+            pass
+        else:
+            return False
     else:
-        res = False
+        try:
+            get_tld(domain)
+        except:
+            return False
     return res
 
 
@@ -98,26 +108,6 @@ def is_ipv4_cidr(target):
         target)
 
 
-def get_ip_from_target(url):
-    try:
-        domain = get_domain(url)
-        myaddr = socket.getaddrinfo(domain, 'http')
-        return myaddr[0][4][0]
-    except socket.gaierror:
-        logger.warning("{}未能找到ip".format(url))
-        return None
-
-
-def get_domain(site):
-    if site.startswith('http://'):
-        site = site[7:]
-    elif site.startswith("https://"):
-        site = site[8:]
-    if site.endswith('/'):
-        site = site[:-1]
-    return site
-
-
 # ########################分割IP段部分#########################
 
 
